@@ -11,17 +11,23 @@ from pyrho.utils import gaussian_smear, get_sc_interp, interpolate_fourier
 
 
 class PGrid(MSONable):
+    """Class representing of _periodic_ grid data.
+
+    Represents a periodic scalar field on a regular grid. The data is defined by the lattice vectors and the grid data.
+    The grid points are implicitly defined by the lattice vectors and the grid shape.
+
+    """
+
     def __init__(self, grid_data: npt.NDArray, lattice: npt.NDArray):
-        """Base class for N-dimensional Regular period grid data.
+        """Initialize the PGrid object.
 
-        The core code is valid for any N-dimensional periodic data
-
-        Parameters
+        Attributes
         ----------
         grid_data:
             Data stored on the regular rid
         lattice:
             Lattice vectors of the grid
+
         """
         self.grid_data = grid_data
         self.lattice = np.array(lattice)
@@ -36,7 +42,7 @@ class PGrid(MSONable):
         origin: npt.ArrayLike | None = None,
         up_sample: int = 1,
     ) -> npt.NDArray:
-        """Apply a supercell transformation to the grid data
+        """Apply a supercell transformation to the grid data.
 
         This function assumes that the data is fixed in place and the transformation
         is applied to the lattice vectors.
@@ -71,7 +77,7 @@ class PGrid(MSONable):
         return new_data
 
     def __mul__(self, factor: float) -> PGrid:
-        """Multiply the grid data by a factor
+        """Multiply the grid data by a factor.
 
         Parameters
         ----------
@@ -87,7 +93,7 @@ class PGrid(MSONable):
         return PGrid(grid_data=self.grid_data * factor, lattice=self.lattice)
 
     def __truediv__(self, factor: float) -> PGrid:
-        """Divide the grid data by a factor
+        """Divide the grid data by a factor.
 
         Parameters
         ----------
@@ -109,7 +115,7 @@ class PGrid(MSONable):
         origin: npt.NDArray | None = None,
         up_sample: int = 1,
     ) -> PGrid:
-        """Get a new PGrid object for the new transformed data
+        """Get a new PGrid object for the new transformed data.
 
         Parameters
         ----------
@@ -138,16 +144,23 @@ class PGrid(MSONable):
     def lossy_smooth_compression(
         self, grid_out: List, smear_std: float = 0.2
     ) -> npt.NDArray:
-        """
-        Perform Fourier interpolation then Gaussian smoothing.
-        the smoothing makes sure that simple operation like max and min filters still
+        """Perform Fourier interpolation then Gaussian smoothing.
+
+        The smoothing makes sure that simple operation like max and min filters still
         give the same results.
 
-        Args:
-            grid_out: desired output grid of the compressed data,
+        Parameters
+        ----------
+        grid_out:
+            desired output grid of the compressed data.
+        smear_std:
+            standard deviation of the Gaussian smoothing
 
-        Returns:
+        Returns
+        -------
+        NDArray:
             Smoothed array
+
         """
         arr_interp = np.absolute(interpolate_fourier(self.grid_data, grid_out))
         if smear_std > 0:
